@@ -51,14 +51,14 @@ Return a string containing a full description of the cell measure.
 
 :Parameters:
 
-    display : bool, optional
+    display: `bool`, optional
         If False then return the description as a string. By default
         the description is printed, i.e. ``c.dump()`` is equivalent to
         ``print c.dump(display=False)``.
 
 :Returns:
 
-    out : None or str
+    out: `None` or `str`
         A string containing the description.
 
 :Examples:
@@ -112,13 +112,13 @@ The identity is first found of:
 
 :Parameters:
 
-    default : optional
+    default: optional
         If none of `measure`, `standard_name` and `!id` exist then
         return *default*. By default, *default* is None.
 
 :Returns:
 
-    out :
+    out:
         The identity.
 
 :Examples:
@@ -151,20 +151,20 @@ Note that ``c.name(identity=True)`` is equivalent to ``c.identity()``.
 
 :Parameters:
 
-    default : *optional*
+    default: optional
         If no name can be found then return the value of the *default*
         parameter. By default the default is None.
 
-    identity : bool, optional
+    identity: `bool`, optional
         If True then 3. and 4. are not considered as possible names.
 
-    ncvar : bool, optional
+    ncvar: `bool`, optional
         If True then 1., 2., 3. and 4. are not considered as possible
         names.
 
 :Returns:
 
-    out : str
+    out: `str`
         A  name for the cell measure.
 
 :Examples:
