@@ -718,22 +718,25 @@ Cell methods    : time: minimum within years
 
                     if term == 'interval':
                         interval = cell_methods.pop(0)
-                        try:
-                            interval = ast_literal_eval(interval)
-                        except:
-                            raise ValueError(
-                                "Unparseable cell methods interval: %r" % interval)
-
                         if cell_methods[0] != ')':
                             units = cell_methods.pop(0)
                         else:
                             units = None
 
                         try:
-                            intervals.append(Data(interval, units))
+#                            parsed_interval = float(ast_literal_eval(interval))
+                            parsed_interval = ast_literal_eval(interval)
                         except:
                             raise ValueError(
-                                "Unparseable cell methods interval")
+"Unparseable cell methods interval: {0!r}".format(
+    interval+' '+units if units is not None else interval))
+                            
+                        try:
+                            intervals.append(Data(parsed_interval, units))
+                        except:
+                            raise ValueError(
+"Unparseable cell methods interval: {0!r}".format(
+    interval+' '+units if units is not None else interval))
                             
                         continue
                     #--- End: if
