@@ -1,16 +1,15 @@
 import netCDF4
 
 # Work: Running Sphinx v1.2b1
-
-from datetime import datetime
+from datetime  import datetime
 
 from numpy import array     as numpy_array
 from numpy import ndarray   as numpy_ndarray
 from numpy import ndim      as numpy_ndim
 from numpy import vectorize as numpy_vectorize
 
-from .functions import inspect as cf_inspect
-from .units     import Units
+from .functions    import inspect as cf_inspect
+from .units        import Units
 
 if netCDF4.__version__ <= '1.1.1':
     _netCDF4_netcdftime_parse_date = netCDF4.netcdftime._parse_date
@@ -20,6 +19,10 @@ else:
     _netCDF4_netcdftime_strftime   = netCDF4.netcdftime._datetime._strftime
 
 
+# Define some useful units
+_calendar_years  = Units('calendar_years')
+_calendar_months = Units('calendar_months')
+
 # ====================================================================
 #
 # Datetime object (overrides netCDF4.netcdftime.datetime)
@@ -423,7 +426,7 @@ minute, second and microsecond.
             return Datetime(*args)
 #--- End: def
 
-def st2dt(array, units_in, dummy0=None, dummy1=None):
+def st2dt(array, units_in=None, dummy0=None, dummy1=None):
     '''
     
 The returned array is always independent.
@@ -432,7 +435,7 @@ The returned array is always independent.
 
     array: numpy array-like
 
-    units_in: `cf.Units`
+    units_in: `cf.Units`, optional
 
     dummy0: optional
         Ignored.
@@ -449,7 +452,7 @@ The returned array is always independent.
 :Examples:
 
 '''
-    if units_in._calendar in ('gregorian' 'standard', 'none'):
+    if getattr(units_in, '_calendar', None) in ('gregorian' 'standard', 'none'):
         return array_st2datetime(array)
     else:
         return array_st2Datetime(array)
@@ -578,6 +581,46 @@ The returned array is always independent.
     return array
 #--- End: def
 
+def st2rt(array, units_in, units_out, dummy1=None):
+    '''
+    
+The returned array is always independent.
+
+:Parameters:
+
+    array: numpy array-like of ISO 8601 date-time strings
+
+    units_in: `cf.Units` or `None`
+
+    units_out: `cf.Units`
+
+    dummy1:
+        Ignored.
+
+:Returns: 
+
+    out: `numpy.ndarray`
+        An array of floats with the same shape as *array*.
+
+'''
+
+    array = st2dt(array, units_in)
+
+    ndim = numpy_ndim(array)
+    
+    if not ndim and isinstance(array, numpy_ndarray):
+        # This necessary because date2num gets upset if you pass
+        # it a scalar numpy array
+        array = array.item()
+
+    array = units_out._utime.date2num(array)
+    
+    if not ndim:
+        array = numpy_array(array)
+
+    return array
+#--- End: def
+
 def _JulianDayFromDate(date, calendar='standard'):
     '''
 
@@ -691,3 +734,48 @@ if netCDF4.__version__ <= '1.1.1':
     netCDF4.netcdftime._NoLeapDayFromDate = _NoLeapDayFromDate
 else:
     netCDF4.netcdftime.netcdftime._NoLeapDayFromDate = _NoLeapDayFromDate
+
+
+def interval(value, units_in, units_out=None, dummy1=None):
+    '''
+'''
+
+    reftime = units_in.reftime.timetuple()
+    
+    if units == _calendar_years:
+        months = value * 12
+        int_months = int(months)
+        if int_months != months:
+            raise ValueError(
+"Can't create a time interval of a non-integer number of calendar months: %s" % months)
+    elif units == _calendar_months:
+        months = value
+        int_months = int(months)
+        if int_months != months:
+            raise ValueError(
+"Can't create a time interval of a non-integer number of calendar months: %s" % months)
+    else:
+        int_months = None
+
+    if int_months is not None:
+        if value > 0:
+            y, month1 = divmod(reftime[1] + int_months, 12)
+            
+            if not month1:
+                y -= 1
+                month1 = 12
+                
+            year1 = reftime[0] + y
+        
+            dt = Datetime(year1, month1, reftime[2:6])
+        else:
+            y, month0 = divmod(reftime[1] - int_months, 12)
+            
+            if not month0:
+                y -= 1
+                month0 = 12
+                
+            year0 = reftime[0] + y
+            
+            dt = Datetime(year0, month0, reftime[2:6])
+
