@@ -13,6 +13,7 @@ from numpy import integer     as numpy_integer
 #from numpy import isclose     as numpy_isclose
 from numpy import maximum     as numpy_maximum
 from numpy import minimum     as numpy_minimum
+from numpy import ndim        as numpy_ndim
 from numpy import sum         as numpy_sum
 from numpy import where       as numpy_where
 from numpy import zeros       as numpy_zeros
@@ -118,7 +119,7 @@ def pmax(x, y):
             x = numpy_array(x)
     else:
         # x and y are both unmasked
-        if not x.ndim:
+        if not numpy_ndim(x):
             # Make sure that we have a numpy array (as opposed to,
             # e.g. a numpy.float64)
             x = numpy_asanyarray(x)
@@ -166,7 +167,7 @@ def pmin(x, y):
             x = numpy_array(x)
     else:
         # x and y are both unmasked 
-        if not x.ndim:
+        if not numpy_ndim(x):
             # Make sure that we have a numpy array (as opposed to,
             # e.g. a numpy.float64)
             x = numpy_asanyarray(x)
@@ -177,25 +178,23 @@ def pmin(x, y):
 #--- End: def
 
 def mask_where_too_few_values(Nmin, N, x):
-    '''
-
-Mask elements of N and x where N is strictly less than Nmin.
+    '''Mask elements of N and x where N is strictly less than Nmin.
 
 :Parameters:
 
-    Nmin : int
+    Nmin: `int`
 
-    N : numpy array
+    N: `numpy.ndarray`
 
-    x : numpy array
+    x: `numpy.ndarray`
 
 :Returns:
 
-    out : tuple
-        A 2-tuple containing *N* and *x*, both masked where *N* is
+    out: (`numpy.ndarray`, `numpy.ndarray`)
+        A tuple containing *N* and *x*, both masked where *N* is
         strictly less than *Nmin*.
 
-'''
+    '''
     if N.min() < Nmin:
         mask = N < Nmin
         N = numpy_ma_array(N, mask=mask, copy=False, shrink=False)
@@ -233,7 +232,7 @@ axis.
     N    = sample_size_f(a, axis=axis, masked=masked)
     amax = numpy_amax(a, axis=axis)
 
-    if not amax.ndim:
+    if not numpy_ndim(amax):
         # Make sure that we have a numpy array (as opposed to, e.g. a
         # numpy.float64)
         amax = numpy_asanyarray(amax)
@@ -291,7 +290,7 @@ axis.
     N    = sample_size_f(a, axis=axis, masked=masked)
     amin = numpy_amin(a, axis=axis)
 
-    if not amin.ndim:
+    if not numpy_ndim(amin):
         # Make sure that we have a numpy array (as opposed to, e.g. a
         # numpy.float64)
         amin = numpy_asanyarray(amin)
@@ -358,7 +357,7 @@ The weighted average along the specified axes.
 
     avg, sw = average(a, axis=axis, weights=weights, returned=True)
         
-    if not avg.ndim:
+    if not numpy_ndim(avg):
         avg = numpy_asanyarray(avg)
         sw  = numpy_asanyarray(sw)
 
@@ -372,6 +371,9 @@ The weighted average along the specified axes.
 
 def mean_fpartial(out, out1=None):
     '''
+:Returns:
+
+    out: `numpy.ndarray`, `numpy.ndarray`, `numpy.ndarray`
 '''
     N, avg, sw = out
     
@@ -393,9 +395,13 @@ def mean_fpartial(out, out1=None):
 def mean_ffinalise(out, sub_samples=None):
     '''
 
-    sub_samples : *optional*
+    sub_samples: optional
         Ignored.
 
+:Returns:
+
+    out: `numpy.ndarray`, `numpy.ndarray`
+
 '''
     N, avg, sw = out
 
@@ -438,7 +444,7 @@ axis=axis), numpy.amax(a, axis=axis))``
     amin = numpy_amin(a, axis=axis)
     amax = numpy_amax(a, axis=axis)
 
-    if not amin.ndim:
+    if not numpy_ndim(amin):
         # Make sure that we have a numpy array (as opposed to, e.g. a
         # numpy.float64)
         amin = numpy_asanyarray(amin)
@@ -526,7 +532,7 @@ def sample_size_f(a, axis=None, masked=False):
 '''
     if masked:        
         N = numpy_sum(-a.mask, axis=axis, dtype=float)
-        if not N.ndim:
+        if not numpy_ndim(N):
             N = numpy_asanyarray(N)
     else:
         if axis is None:
@@ -609,7 +615,7 @@ axis=axis),)``
     N    = sample_size_f(a, axis=axis, masked=masked)
     asum = a.sum(axis=axis)
 
-    if not asum.ndim:
+    if not numpy_ndim(asum):
         asum = numpy_asanyarray(asum)
 
     return N, asum
@@ -654,7 +660,7 @@ def sw_f(a, axis=None, masked=False, weights=None):
             weights = numpy_ma_array(weights, mask=a.mask, copy=False)
 
         sw = weights.sum(axis=axis)
-        if not sw.ndim:
+        if not numpy_ndim(sw):
             sw = numpy_asanyarray(sw)
     else:
         sw = N.copy()
@@ -681,7 +687,7 @@ def sw2_f(a, axis=None, masked=False, weights=None):
             weights = numpy_ma_array(weights, mask=a.mask, copy=False)
 
         sw2 = (weights*weights).sum(axis=axis)
-        if not sw2.ndim:
+        if not numpy_ndim(sw2):
             sw2 = numpy_asanyarray(sw2)
     else:
         sw2 = N.copy()
@@ -698,6 +704,9 @@ sw2_ffinalise = sum_ffinalise
 def var_f(a, axis=None, weights=None, masked=False, ddof=1, f=None):
     '''
 
+:Return:
+    out: 8-`tuple` of `numpy.ndarray`
+
 ''' 
     # ----------------------------------------------------------------
     # Find the minimum and maximum values of the weights if required
@@ -751,7 +760,7 @@ def var_f(a, axis=None, weights=None, masked=False, ddof=1, f=None):
         shape = avg.shape        
         avg = avg.reshape(shape[:axis] + shape[axis+1:])
 
-    if not var.ndim:
+    if not numpy_ndim(var):
         var = numpy_asanyarray(var)
 
     return N, var, avg, sw, ddof, f, wmin, wmax
