@@ -1,6 +1,8 @@
-from numpy import save    as numpy_save
-from numpy import ndarray as numpy_ndarray
+from numpy import empty   as numpy_empty
+from numpy import full    as numpy_full
 from numpy import load    as numpy_load
+from numpy import ndarray as numpy_ndarray
+from numpy import save    as numpy_save
 
 from numpy.ma import array     as numpy_ma_array
 from numpy.ma import is_masked as numpy_ma_is_masked
@@ -294,7 +296,7 @@ Returns a numpy array.
 
         '''
         array_shape = []
-        for index in parse_indices(self.shape, indices):
+        for index in parse_indices(self, indices):
             if isinstance(index, slice):                
                 step = index.step
                 if step == 1:
