@@ -583,12 +583,20 @@ cell_methods)
             #--- End: if
 
             dim = f.domain.insert_dim(coord, copy=False)
+            
+            # Set unlimited status of axis
+            if nc.dimensions[ncdim].isunlimited():
+                f.unlimited({dim: True})
 
             ncvar_to_key[ncdim] = dim
         else:
             # There is no dimension coordinate for this dimension, so
             # just create a dimension with the correct size.
             dim = f.domain.insert_axis(size=len(nc.dimensions[ncdim]))
+
+            # Set unlimited status of axis
+            if nc.dimensions[ncdim].isunlimited():
+                f.unlimited({dim: True})
         #--- End: if
         
         # Update data dimension name and set dimension size
@@ -1293,13 +1301,16 @@ False
     try:
         fh = open(filename, 'rb')
         magic_number = struct_unpack('=L', fh.read(4))[0]
-    except struct_error:
+    except:
+        magic_number = None
+
+    try:
         fh.close()
-        return False
+    except:
+        pass
+
+    if magic_number in (21382211, 1128547841, 1178880137, 38159427):
+        return True
     else:
-        fh.close()        
-        if magic_number in (21382211, 1128547841, 1178880137, 38159427):
-            return True
-        else:
-            return False
+        return False
 #--- End: def
