@@ -34,12 +34,16 @@ from ..data.data        import Data
 from .filearray import NetCDFFileArray
 from .functions import _close_netcdf_file, _open_netcdf_file
 
+class NetCDFError(Exception):
+    '''A runtime netCDF error'''
+    pass
+
 def write(fields, filename, fmt='NETCDF3_CLASSIC', overwrite=True,
           verbose=False, cfa_options=None, mode='w',
           least_significant_digit=None, endian='native', compress=0,
           fletcher32=False, no_shuffle=False, datatype=None,
           single=False, double=False, reference_datetime=None,
-          variable_attributes=None, HDF_chunks=None):
+          variable_attributes=None, HDF_chunks=None, unlimited=None):
     '''Write fields to a CF-netCDF or CFA-netCDF file.
     
 NetCDF dimension and variable names will be taken from variables'
@@ -250,6 +254,9 @@ and auxiliary coordinate roles for different data variables.
             dtype_conversions[numpy_dtype('float32')] = numpy_dtype(float)
             dtype_conversions[numpy_dtype('int32')]   = numpy_dtype(int)
     datatype = dtype_conversions
+    
+    if not unlimited:
+        unlimited = ()
 
     # ----------------------------------------------------------------
     # Initialize dictionary of useful global variables
@@ -324,11 +331,15 @@ and auxiliary coordinate roles for different data variables.
          # ------------------------------------------------------------
          # Specify data type conversions to be applied prior to writing
          # ------------------------------------------------------------
-         'datatype'               : datatype,
+         'datatype': datatype,
          # ------------------------------------------------------------
          # Specify unit conversions to be applied prior to writing
          # ------------------------------------------------------------
-         'reference_datetime'     : reference_datetime,
+         'reference_datetime': reference_datetime,
+         # ------------------------------------------------------------
+         # 
+         # ------------------------------------------------------------
+         'unlimited': unlimited,
     }
 
     if fmt == 'CFA3':
@@ -342,6 +353,8 @@ and auxiliary coordinate roles for different data variables.
         if cfa_options:
             g['cfa_options'] = cfa_options  
     
+    g['fmt'] = fmt
+
     # ---------------------------------------------------------------
     # Flatten the sequence of intput fields
     # ---------------------------------------------------------------
@@ -1052,32 +1065,33 @@ def _variable_ncvar(variable, default, counter, g=None):
     return _check_name(ncvar, counter, g=g)        
 #--- End: def
     
-def _write_dimension(ncdim, f, axis, axis_to_ncdim, is_unlimited=False, g=None):
+def _write_dimension(ncdim, f, axis, axis_to_ncdim, unlimited=False, g=None):
     '''Write a dimension to the netCDF file.
 
 .. note:: This function updates ``axis_to_ncdim``, ``g['ncdim_to_size']``.
 
 :Parameters:
 
-    ncdim : str
+    ncdim: `str`
         The netCDF dimension name.
 
-    f : cf.Field
+    f: `cf.Field`
    
-    axis : str
+    axis: `str`
         The field's axis identifier.
 
-    axis_to_ncdim : dict
+    axis_to_ncdim: `dict`
         Mapping of field axis identifiers to netCDF dimension names.
 
-    is_unlimited : bool, optional
-        If true then create an unlimited dimension
+    unlimited: `bool`, optional
+        If true then create an unlimited dimension. By default
+        dimensions are not unlimited.
 
-    g : dict
+    g: `dict`
 
 :Returns:
 
-     None
+     `None`
 
     '''          
     size = f.axis_size(axis)
@@ -1085,10 +1099,28 @@ def _write_dimension(ncdim, f, axis, axis_to_ncdim, is_unlimited=False, g=None):
     g['ncdim_to_size'][ncdim] = size
     axis_to_ncdim[axis] = ncdim
 
-    if is_unlimited:
-        g['netcdf'].createDimension(ncdim, None)
+    if unlimited:
+        # Create an unlimited dimension
+        try:
+            g['netcdf'].createDimension(ncdim, None)
+        except RuntimeError as error:
+
+            message = "Can't create unlimited dimension in {} file ({}).".format(
+                g['netcdf'].file_format, error)
+
+            error = str(error)
+            if error == 'NetCDF: NC_UNLIMITED size already in use':
+                raise NetCDFError(
+message+" Only one unlimited dimension allowed. Consider using a netCDF4 format.")
+                
+            raise NetCDFError(message)
     else:
-        g['netcdf'].createDimension(ncdim, size)
+        try:
+            g['netcdf'].createDimension(ncdim, size)
+        except RuntimeError as error:
+            raise NetCDFError(
+"Can't create dimension of size {} in {} file ({})".format(
+    size, g['netcdf'].file_format, error))
 #--- End: def
 
 def _change_reference_datetime(coord, g=None):
@@ -1177,9 +1209,9 @@ a new netCDF bounds dimension.
 
         # Create a new dimension, if it is not a scalar coordinate
         if coord.ndim > 0:
-            is_unlimited = getattr(coord, 'is_unlimited', False)
+            unlimited = _unlimited(f, axis, g=g)
             _write_dimension(ncdim, f, axis, axis_to_ncdim,
-                             is_unlimited=is_unlimited, g=g)
+                             unlimited=unlimited, g=g)
 
         ncdimensions = _grid_ncdimensions(f, axis, axis_to_ncdim, g=g)
         
@@ -1780,11 +1812,23 @@ created. The ``seen`` dictionary is updated for *cfvar*.
                 chunksizes=chunksizes,
                 **g['compression']
             )
-        except (TypeError, RuntimeError):
-            raise TypeError(
-"Can't write data type {0!r} (from {1!r}) to a {2} file. Use a netCDF4 format or use the 'single' or 'datatype' parameters or change the datatype before writing".format(
-    datatype, cfvar, g['netcdf'].file_format))
+#        except (TypeError, RuntimeError):
+        except RuntimeError as error:
+            error = str(error)
+            if error == 'NetCDF: Not a valid data type or _FillValue type mismatch':
+                raise ValueError(
+"Can't write {0} data from {1!r} to a {2} file. Consider using a netCDF4 format or use the 'single' or 'datatype' parameters or change the datatype before writing.".format(
+    cfvar.dtype.name, cfvar, g['netcdf'].file_format))
             
+            message = "Can't create variable in {} file from {} ({})".format(g['netcdf'].file_format, cfvar, error)
+
+            if error == 'NetCDF: NC_UNLIMITED in the wrong index':            
+                raise NetCDFError(
+message+". Unlimited dimension must be the first (leftmost) dimension of the variable. Consider using a netCDF4 format.")
+                
+            raise NetCDFError(message)
+        #--- End: try
+
         _write_attributes(g['nc'][ncvar], netcdf_attrs)
 
         #-------------------------------------------------------------
@@ -1811,13 +1855,13 @@ created. The ``seen`` dictionary is updated for *cfvar*.
 
             pda_args['revert_to_file'] = True
             
-            if data._isdt:
-                # Convert date-time objects to numeric reference times
-                pda_args['func']   = dt2rt
-                # Turn off data type checking and partition updating
-                pda_args['dtype']  = None
-                pda_args['update'] = False
-            #--- End: if
+#            if data._isdt:
+#                # Convert date-time objects to numeric reference times
+#                pda_args['func']   = dt2rt
+#                # Turn off data type checking and partition updating
+#                pda_args['dtype']  = None
+#                pda_args['update'] = False
+#            #--- End: if
 
             convert_dtype = g['datatype']
 
@@ -1909,6 +1953,7 @@ def _write_a_field(f, add_to_seen=False, allow_data_expand_dims=True,
     # Initialize the list of the field's auxiliary coordinates
     coordinates = []
 
+    # For each of the field's axes ...
     for axis in sorted(f.axes()):
         
         dim_coord = f.dim(axis)
@@ -1959,7 +2004,7 @@ def _write_a_field(f, add_to_seen=False, allow_data_expand_dims=True,
                 # the data array to include it.
                 f.expand_dims(0, axes=axis, i=True)
                 data_axes.append(axis)
-
+                
             # If the data array (now) spans this axis then create a
             # netCDF dimension for it
             if axis in data_axes:
@@ -1970,9 +2015,9 @@ def _write_a_field(f, add_to_seen=False, allow_data_expand_dims=True,
                     
                 ncdim, g['dimN'] = _check_name(ncdim, g['dimN'], g=g)
 
-                _write_dimension(ncdim, f, axis, axis_to_ncdim, g=g)
-        #--- End: if
-
+                unlimited = _unlimited(f, axis, g=g)
+                _write_dimension(ncdim, f, axis, axis_to_ncdim,
+                                 unlimited=unlimited, g=g)
     #--- End: for
 
     # ----------------------------------------------------------------
@@ -2160,6 +2205,21 @@ def _write_a_field(f, add_to_seen=False, allow_data_expand_dims=True,
                            'ncdims'  : ncdimensions}
 #--- End: def
 
+def _unlimited(f, axis, g=None):
+    '''
+'''
+    unlimited = f.unlimited().get(axis)
+
+    if unlimited is None:
+        unlimited = False
+        for u in g['unlimited']:
+            if f.axis(u) == axis:
+                unlimited = True
+                break
+    
+    return unlimited
+#--- End: def
+
 def _create_global_properties(fields, g=None):
     '''
 
