@@ -185,29 +185,36 @@ Attribute        Description
 
 :Parameters:
 
-    operator: str
+    operator: `str`
         The query operator.
 
     value:
         The right hand side of the query operation.
 
-    units: str or cf.Units, optional
+    units: `str` or `cf.Units`, optional
         The units of *value*. By default, the same units, if any, as
         the left hand side of the query operation are assumed.
 
-    exact: bool, optional
+    exact: `bool`, optional
         If False then string values are treated as a regular
         expressions as understood by the :py:obj:`re` module and are
         evaluated using the :py:obj:`re.match` method. Ignored for
         all operators except ``'eq'``, ``'ne'`` and ``'set'``.
 
-    attr: str, optional
-        Specify an attribute name such that this attribute of the left
-        hand side operand is compared, rather than the operand itself.
+    attr: `str`, optional
+        Specify an attribute (or an attribute of an attribute, etc.)
+        of a left hand side operand which is compared, rather than the
+        operand itself.
 
           *Example:*
-            ``cf.Query('ge', 2, attr='ndim')`` with return True when
-            evaluated for an array with two or more dimensions.
+            ``cf.Query('ge', 2, attr='ndim')`` will return True when
+            evaluated for a numpy array with two or more dimensions.
+
+          *Example:* 
+            ``q=cf.Query('ge', 2, attr='lower_bounds.month')`` will
+            compare the `month` attribute of the `lower_bounds`
+            attribute. I.e. ``q==x`` is equivalent to ``cf.Query('ge',
+            2)==x.lower_bounds.month``.
 
 :Examples:
 
@@ -243,7 +250,12 @@ Attribute        Description
         self._value    = value
         self._exact    = exact
         self._compound = False
-        self._attr     = () if not attr else (attr,)
+
+#        self._attr     = () if not attr else (attr,)
+        if attr:
+            self._attr = tuple(attr.split('.'))
+        else:
+            self._attr = ()
 
         self._bitwise_operator = None
 
