@@ -49,7 +49,7 @@ Office (UK) fields files format files may be read.
 
 :Parameters:
 
-    files : (arbitrarily nested sequence of) str
+    files: (arbitrarily nested sequence of) `str`
 
         A string or arbitrarily nested sequence of strings giving the
         file names or OPenDAP URLs from which to read fields. Various
@@ -83,10 +83,10 @@ Office (UK) fields files format files may be read.
           ``'~david/*.nc'``, which will read all netCDF files in the
           user david's home directory.
   
-    verbose : bool, optional
+    verbose: `bool`, optional
         If True then print information to stdout.
     
-    umversion : int or float, optional
+    umversion: `int` or `float`, optional
         Met Office (UK) PP files and Met Office (UK) fields files
         only, the Unified Model (UM) version to be used when decoding
         the PP header. Valid versions are, for example, ``402`` or
@@ -100,12 +100,12 @@ Office (UK) fields files format files may be read.
     
         Ignored for any other type of input files.
 
-    ignore_read_error : bool, optional
+    ignore_read_error: `bool`, optional
         If True then ignore any file which raises an IOError whilst
         being read, as would be the case for an empty file, unknown
         file format, etc. By default the IOError is raised.
     
-    fmt : str, optional
+    fmt: `str`, optional
         Only read files of the given format, ignoring all other
         files. Valid formats are ``'NETCDF'`` for CF-netCDF files,
         ``'CFA'`` for CFA-netCDF files and ``'PP'`` for PP files and
@@ -113,7 +113,7 @@ Office (UK) fields files format files may be read.
         formats are read.  default files of any of these formats are
         read.
 
-    aggregate : bool or dict, optional
+    aggregate: `bool` or `dict`, optional
         If True (the default) or a (possibly empty) dictionary then
         aggregate the fields read in from all input files into as few
         fields as possible using the CF aggregation rules. If
@@ -121,20 +121,20 @@ Office (UK) fields files format files may be read.
         arguments to the `cf.aggregate` function. If False then the
         fields are not aggregated.
 
-    squeeze : bool, optional
+    squeeze: `bool`, optional
         If True then remove size 1 axes from each field's data array.
 
-    unsqueeze : bool, optional
+    unsqueeze: `bool`, optional
         If True then insert size 1 axes from each field's domain into
         its data array.
 
-    select, select_options : *optional*
+    select, select_options: optional
         Only return fields which satisfy the given conditions on their
         property values. Only fields which, prior to any aggregation,
         satisfy ``f.match(select, **select_options) == True`` are
         returned. See `cf.Field.match` for details.
 
-    top_level : (sequence of) str, optional
+    top_level: (sequence of) `str`, optional
         Promote field components to independent top-level fields. The
         *top_level* parameter may be or, or a sequence, of:
 
@@ -160,14 +160,14 @@ Office (UK) fields files format files may be read.
 
         .. versionadded:: 1.0.4
 
-    recursive : bool, optional
+    recursive: `bool`, optional
         If True then allow directories to be specified by the *files*
         parameter and recursively search the directories for files to
         read.
 
         .. versionadded:: 1.1.9
 
-    follow_symlinks : bool, optional
+    follow_symlinks: `bool`, optional
         If True, and *recursive* is True, then also search for files
         in directories which resolve to symbolic links. By default
         directories which resolve to symbolic links are
@@ -181,7 +181,7 @@ Office (UK) fields files format files may be read.
         .. versionadded:: 1.1.9
 :Returns:
     
-    out : cf.FieldList or cf.Field
+    out: `cf.FieldList` or `cf.Field`
         A list of fields, or if there is only one field, the
         individual field.
 
@@ -492,17 +492,17 @@ def file_type(filename):
 
 :Parameters:
 
-    filename : str
+    filename: `str`
         The file name.
 
 :Returns:
 
-    out : str
+    out: `str`
         The format type of the file.
 
 :Raises:
  
-    IOError :
+    IOError:
         If the file has an unsupported format.
 
 :Examples:
