@@ -8,7 +8,10 @@ from .coordinate import DimensionCoordinate
 from .functions import REGRID_LOGGING
 from . import _found_ESMF
 if _found_ESMF:
-    import ESMF
+    try:
+        import ESMF
+    except Exception as error:
+        print("WARNING: Can not import ESMF for regridding: {0}".format(error))
 
 class Regrid:
     """
