@@ -1,9 +1,11 @@
 import operator
 
-from datetime import datetime
+from datetime  import datetime
+from functools import partial as functools_partital
 
 from numpy import array     as numpy_array
 from numpy import size      as numpy_size
+from numpy import vectorize as numpy_vectorize
 
 from cfdatetime import Datetime
 from .functions import equals
@@ -1146,7 +1148,7 @@ Create ISO 8601 time interval strings:
             else:
                 dt1 -= duration
 
-            dt1 = dt1.asdatetime().datum()
+            dt1 = dt1.dtarray.item((0,)*dt1.ndim) #asdatetime().datum()
             
             if not end:
                 return dt, dt1
@@ -1677,3 +1679,43 @@ def s(duration=1, year=None, month=1, day=1, hour=0, minute=0, second=0):
     return TimeDuration(duration, 'seconds', year=year, month=month, day=day, 
                         hour=hour, minute=minute, second=second)
 #--- End: def
+
+def _convert_reftime_units(value, units):
+    duration_units = units._utime.units
+    if not duration_units.startswith('calendar_'):
+        duration_units = 'calendar_'+duration_units
+    t = TimeDuration(value, units=duration_units)
+    reftime = units.reftime.timetuple()[:6]
+    if value > 0:
+        return t.interval(*reftime, calendar=units._calendar, end=False)[1]
+    else:
+        return t.interval(*reftime, calendar=units._calendar, end=True)[0]
+#--- End: def
+
+def fix_reftime_units(data, units=None):
+    '''
+    
+The returned array is always independent.
+
+:Parameters:
+
+    data: `cf.Data`
+
+    units: `cf.Units`
+
+:Returns: 
+
+    out: `cf.Data`
+
+
+'''
+    f = functools_partital(_convert_reftime_units, units=data.Units)
+
+    if units is None:
+        units = data.Units
+        units = Units('days since '+units.units.split(' since ')[1], calendar=units._calendar)
+    elif not units.isreftime:
+        raise ValueError("'units' parameter must be reference time units")
+
+    return Data(numpy_vectorize(f, otypes=[object])(data), units=units)
+#--- End: def
