@@ -5,7 +5,8 @@ def write(fields, filename, fmt='NETCDF3_CLASSIC', overwrite=True,
           least_significant_digit=None, endian='native', compress=0,
           fletcher32=False, no_shuffle=False, datatype=None,
           single=False, double=False, reference_datetime=None,
-          variable_attributes=None, HDF_chunksizes=None):
+          variable_attributes=None, HDF_chunksizes=None,
+          unlimited=None):
     '''Write fields to a CF-netCDF or CFA-netCDF file.
     
 NetCDF dimension and variable names will be taken from variables'
@@ -215,13 +216,32 @@ and auxiliary coordinate roles for different data variables.
         closely as possible the size and shape of the data block that
         users will read from the file.
 
+    unlimited: sequence of `str`, optional
+
+        Create a unlimited dimensions (dimensions that can be appended
+        to). A dimension is identified by either a standard name; one
+        of T, Z, Y, X denoting time, height or horixontal axes (as
+        defined by the CF conventions); or the value of an arbitrary
+        CF property preceeded by the property name and a colon. For
+        example:
+
+         Multiple unlimited axes may be defined by specifying more
+         than one --unlimited option. Note, however, that only netCDF4
+         formats support multiple unlimited dimensions. For example,
+         to set the time and Z dimensions to be unlimited you could
+         use --unlim- ited=time --unlimited=Z
+
+              An example of defining an axis by an arbitrary CF property could
+              be --unlimited=long_name:pseudo_level
+
+       
 :Returns:
 
-    None
+    `None`
 
 :Raises:
 
-    IOError :
+    IOError:
         If *overwrite* is False and the output file pre-exists.
 
 :Examples:
@@ -260,5 +280,5 @@ and auxiliary coordinate roles for different data variables.
                      datatype=datatype, single=single, double=double,
                      reference_datetime=reference_datetime,
                      variable_attributes=variable_attributes,
-                     HDF_chunks=HDF_chunksizes)
+                     HDF_chunks=HDF_chunksizes, unlimited=unlimited)
 #--- End: def
