@@ -31,6 +31,20 @@ class CoordinateReferenceTest(unittest.TestCase):
         #        print
         self.assertTrue(t.equals(t.copy(), traceback=True))
     #--- End: def
+
+    def test_Field_ref_refs(self):
+        f = cf.read(self.filename)[0]
+        
+        self.assertTrue(f.ref('BLAH') is None)
+        self.assertTrue(f.ref('atmos', key=True) == 'ref0')
+        self.assertTrue(f.ref('atmos', key=True, inverse=True) == 'ref1')
+
+        self.assertTrue(set(f.refs()) == set(['ref0', 'ref1']))
+        self.assertTrue(set(f.refs('BLAH')) == set())
+        self.assertTrue(set(f.refs('rot')) == set(['ref1']))
+        self.assertTrue(set(f.refs('rot', inverse=True)) == set(['ref0']))
+        self.assertTrue(set(f.refs('atmosphere_hybrid_height_coordinate', exact=True)) == set(['ref0']))
+    #--- End: def
 #--- End: class
 
 if __name__ == '__main__':
