@@ -26,6 +26,7 @@ class DataTest(unittest.TestCase):
 
     test_only = ()
 #    test_only = ('NOTHING!!!!!')
+#    test_only = ['test_Data__asdatetime__asreftime__isdatetime']
 #    test_only = ('test_Data__collapse_UNWEIGHTED_MASKED',)
 #    test_only = ('test_Data__collapse_UNWEIGHTED_UNMASKED',)
 #    test_only = ('test_Data__collapse_WEIGHTED_UNMASKED',)
@@ -206,6 +207,10 @@ class DataTest(unittest.TestCase):
             self.assertTrue((a2 == b).all())
             self.assertFalse((a2 == a).all())
 
+            d = cf.Data([['2000-12-3 12:00']], 'days since 2000-12-01', dt=True)
+            a = d.array
+            self.assertTrue((a == numpy.array([[2.5]])).all())
+
         cf.CHUNKSIZE(self.original_chunksize)
     #--- End: def
 
@@ -265,7 +270,7 @@ class DataTest(unittest.TestCase):
                                                 cf.dt('2000-12-2 12:00')]])).all())
     #--- End: def
 
-    def test_Data_asdatetime_asreftime(self):
+    def test_Data__asdatetime__asreftime__isdatetime(self):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
 
@@ -273,19 +278,19 @@ class DataTest(unittest.TestCase):
             cf.CHUNKSIZE(chunksize)          
             d = cf.Data([[1.93, 5.17]], 'days since 2000-12-29')
             self.assertTrue(d.dtype == numpy.dtype(float))
-            self.assertFalse(d._isdt)
-            d.asreftime(i=True)
+            self.assertFalse(d._isdatetime())
+            d._asreftime(i=True)
             self.assertTrue(d.dtype == numpy.dtype(float))
-            self.assertFalse(d._isdt)
-            d.asdatetime(i=True)
+            self.assertFalse(d._isdatetime())
+            d._asdatetime(i=True)
             self.assertTrue(d.dtype == numpy.dtype(object))
-            self.assertTrue(d._isdt)
-            d.asdatetime(i=True)
+            self.assertTrue(d._isdatetime())
+            d._asdatetime(i=True)
             self.assertTrue(d.dtype == numpy.dtype(object))
-            self.assertTrue(d._isdt)
-            d.asreftime(i=True)
+            self.assertTrue(d._isdatetime())
+            d._asreftime(i=True)
             self.assertTrue(d.dtype == numpy.dtype(float))
-            self.assertFalse(d._isdt)
+            self.assertFalse(d._isdatetime())
 #            print "pmshape =", d._pmshape
 
         cf.CHUNKSIZE(self.original_chunksize)
