@@ -6,27 +6,24 @@ import inspect
 import datetime
 
 class FieldTest(unittest.TestCase):
-    filename = os.path.join(os.path.dirname(os.path.abspath(__file__)),
-                            'test_file.nc')
-
-    filename2 = os.path.join(os.path.dirname(os.path.abspath(__file__)),
-                             'test_file2.nc')
-
-    chunk_sizes = (17, 34, 300, 100000)[::-1]
-    original_chunksize = cf.CHUNKSIZE()
-
-    f = cf.read(filename)[0]  
-
-    test_only = ()
-#    test_only = ('test_Field_transpose','test_Field_squeeze',)
-#    test_only = ('test_Field_collapse',)
-#    test_only = ('test_Field_match','test_Field_items',)
-#    test_only = ('test_Field_items',)
-#    test_only = ('test_Field_axes','test_Field_data_axes',)
-#    test_only = ('test_Field_where',)
-#    test_only = ('test_Field_anchor',)
-#    test_only = ('test_Field_period',)
-#    test_only = ('test_FieldList_argless_methods',)
+    def setUp(self):
+        self.filename = os.path.join(os.path.dirname(os.path.abspath(__file__)),
+                                     'test_file.nc')
+        self.filename2 = os.path.join(os.path.dirname(os.path.abspath(__file__)),
+                                      'test_file2.nc')
+        self.chunk_sizes = (17, 34, 300, 100000)[::-1]
+        self.original_chunksize = cf.CHUNKSIZE()
+        self.f = cf.read(self.filename)[0]
+        self.test_only = ()
+        # self.test_only = ('test_Field_transpose','test_Field_squeeze',)
+        # self.test_only = ('test_Field_collapse',)
+        # self.test_only = ('test_Field_match','test_Field_items',)
+        # self.test_only = ('test_Field_items',)
+        # self.test_only = ('test_Field_axes','test_Field_data_axes',)
+        # self.test_only = ('test_Field_where',)
+        # self.test_only = ('test_Field_anchor',)
+        # self.test_only = ('test_Field_period',)
+        # self.test_only = ('test_FieldList_argless_methods',)
 
     def test_Field_anchor(self):  
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
