@@ -113,8 +113,69 @@ class TimeDurationTest(unittest.TestCase):
                         (cf.dt('1981-10-26 22:27:14'), cf.dt('1984-02-03 00:00:00')))
     #--- End: def
 
-#--- End: class
+    def test_TimeDuration_bounds(self):        
+        for direction in (True, False):
+            for x, y in zip(
+                    [cf.Y().bounds(1984, 1, 1, direction=direction),
+                     cf.Y().bounds(1984, 12, 1, direction=direction),
+                     cf.Y().bounds(1984, 12, 3, direction=direction),
+                     cf.Y(month=9).bounds(1984, 1, 1, direction=direction),
+                     cf.Y(month=9).bounds(1984, 3, 3, direction=direction),
+                     cf.Y(month=9).bounds(1984, 9, 20, direction=direction),
+                     cf.Y(month=9, day=13).bounds(1984, 12, 12, direction=direction),
+                 ],
+                    [(cf.dt('1984-01-01'), cf.dt('1985-01-01')),
+                     (cf.dt('1984-01-01'), cf.dt('1985-01-01')),
+                     (cf.dt('1984-01-01'), cf.dt('1985-01-01')),
+                     (cf.dt('1983-09-01'), cf.dt('1984-09-01')),
+                     (cf.dt('1983-09-01'), cf.dt('1984-09-01')),
+                     (cf.dt('1984-09-01'), cf.dt('1985-09-01')),
+                     (cf.dt('1984-09-13'), cf.dt('1985-09-13')),
+                 ]):
+                if direction is False:
+                    y = y[::-1]
+                self.assertTrue(x==y, "{}!={}".format(x, y))
 
+            for x, y in zip(
+                    [cf.M().bounds(1984, 1, 1, direction=direction),
+                     cf.M().bounds(1984, 12, 1, direction=direction),
+                     cf.M().bounds(1984, 12, 3, direction=direction),
+                     cf.M(day=15).bounds(1984, 12, 1, direction=direction),
+                     cf.M(day=15).bounds(1984, 12, 3, direction=direction),
+                     cf.M(day=15).bounds(1984, 12, 15, direction=direction),
+                     cf.M(day=15).bounds(1984, 12, 20, direction=direction),
+                 ],
+                    [(cf.dt('1984-01-01'), cf.dt('1984-02-01')),
+                     (cf.dt('1984-12-01'), cf.dt('1985-01-01')),
+                     (cf.dt('1984-12-01'), cf.dt('1985-01-01')),
+                     (cf.dt('1984-11-15'), cf.dt('1984-12-15')),
+                     (cf.dt('1984-11-15'), cf.dt('1984-12-15')),
+                     (cf.dt('1984-12-15'), cf.dt('1985-01-15')),
+                     (cf.dt('1984-12-15'), cf.dt('1985-01-15')),
+                 ]):
+                if direction is False:
+                    y = y[::-1]
+                self.assertTrue(x==y, "{}!={}".format(x, y))
+
+            for x, y in zip(
+                    [cf.D().bounds(1984, 1, 1, direction=direction),
+                     cf.D().bounds(1984, 12, 3, direction=direction),
+                     cf.D(hour=15).bounds(1984, 12, 1, direction=direction),
+                     cf.D(hour=15).bounds(1984, 12, 1, 12, direction=direction),
+                     cf.D(hour=15).bounds(1984, 12, 1, 15, direction=direction),
+                     cf.D(hour=15).bounds(1984, 12, 1, 20, direction=direction),
+                 ],
+                    [(cf.dt('1984-01-01'), cf.dt('1984-01-02')),
+                     (cf.dt('1984-12-03'), cf.dt('1984-12-04')),
+                     (cf.dt('1984-11-30 15:00'), cf.dt('1984-12-01 15:00')),
+                     (cf.dt('1984-11-30 15:00'), cf.dt('1984-12-01 15:00')),
+                     (cf.dt('1984-12-01 15:00'), cf.dt('1984-12-02 15:00')),
+                     (cf.dt('1984-12-01 15:00'), cf.dt('1984-12-02 15:00')),
+                 ]):
+                if direction is False:
+                    y = y[::-1]
+                self.assertTrue(x==y, "{}!={}".format(x, y))
+    #--- End: def
 
 #--- End: class
 
