@@ -29,6 +29,7 @@ class read_writeTest(unittest.TestCase):
 #    test_only = ['NOTHING!!!!!']
 #    test_only = ['test_write_reference_datetime']
 #    test_only = ['test_write_HDF_chunks']
+    test_only = ['test_read_write_unlimited']
 
     def test_read_select(self):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
@@ -158,6 +159,102 @@ class read_writeTest(unittest.TestCase):
         cf.CHUNKSIZE(self.original_chunksize) 
     #--- End: def
 
+    def test_read_write_unlimited(self):
+        if self.test_only and inspect.stack()[0][3] not in self.test_only:
+            return
+        f = cf.read(self.filename)[0]
+
+        fmt = 'NETCDF4'
+        for axis in ('atmosphere_hybrid_height_coordinate', 'X', 'Y'):
+            org = f.unlimited({axis: True})
+            cf.write(f, tmpfile, fmt=fmt)
+            f.unlimited(org)
+            
+            g = cf.read(tmpfile)
+            self.assertTrue(g.unlimited()[g.axis(axis)] is True,
+                            'Failed with axis={}, fmt={}'.format(axis, fmt))
+
+        fmt = 'NETCDF3_CLASSIC'
+        for axis in ('atmosphere_hybrid_height_coordinate',):
+            org = f.unlimited({axis: True})
+            cf.write(f, tmpfile, fmt=fmt)
+            f.unlimited(org)
+            
+            g = cf.read(tmpfile)
+            self.assertTrue(g.unlimited()[g.axis(axis)] is True,
+                            'Failed with axis={}, fmt={}'.format(axis, fmt))
+
+        fmt = 'NETCDF4'
+        org = f.unlimited({'Y': True, 'X': True})
+        cf.write(f, tmpfile, fmt=fmt)
+        f.unlimited(org)
+
+        g = cf.read(tmpfile)
+        self.assertTrue(g.unlimited()[g.axis('X')] is True,
+                        'Failed with axis={}, fmt={}'.format('X', fmt))
+        self.assertTrue(g.unlimited()[g.axis('Y')] is True,
+                        'Failed with axis={}, fmt={}'.format('Y', fmt))
+
+
+        fmt = 'NETCDF4'
+        org = f.unlimited({'X': False})
+        cf.write(f, tmpfile, fmt=fmt, unlimited=['X'])
+        f.unlimited(org)
+
+        g = cf.read(tmpfile)
+        self.assertTrue(not g.unlimited()[g.axis('X')],
+                        'Failed with axis={}, fmt={}'.format('X', fmt))
+
+
+        fmt = 'NETCDF4'
+        org = f.unlimited({'X': True})
+        cf.write(f, tmpfile, fmt=fmt, unlimited=['X'])
+        f.unlimited(org)
+
+        g = cf.read(tmpfile)
+        self.assertTrue(g.unlimited()[g.axis('X')] is True,
+                        'Failed with axis={}, fmt={}'.format('X', fmt))
+
+
+        fmt = 'NETCDF4'
+        org = f.unlimited({'Y': True})
+        cf.write(f, tmpfile, fmt=fmt, unlimited=['X'])
+        f.unlimited(org)
+
+        g = cf.read(tmpfile)
+        self.assertTrue(g.unlimited()[g.axis('X')] is True,
+                        'Failed with axis={}, fmt={}'.format('X', fmt))
+        self.assertTrue(g.unlimited()[g.axis('Y')] is True,
+                        'Failed with axis={}, fmt={}'.format('Y', fmt))
+
+ 
+
+        fmt = 'NETCDF4'
+        org = f.unlimited({('X', 'Y'): True})
+        cf.write(f, tmpfile, fmt=fmt)
+        f.unlimited(org)
+
+        g = cf.read(tmpfile)
+        self.assertTrue(g.unlimited()[g.axis('X')] is True,
+                        'Failed with axis={}, fmt={}'.format('X', fmt))
+        self.assertTrue(g.unlimited()[g.axis('Y')] is True,
+                        'Failed with axis={}, fmt={}'.format('Y', fmt))
+
+ 
+
+        fmt = 'NETCDF4'
+        org = f.unlimited({('X', 'Y'): True})
+        f.unlimited(None)
+        cf.write(f, tmpfile, fmt=fmt)
+        f.unlimited(org)
+
+        g = cf.read(tmpfile)
+        self.assertTrue(not g.unlimited()[g.axis('X')],
+                        'Failed with axis={}, fmt={}'.format('X', fmt))
+        self.assertTrue(not g.unlimited()[g.axis('Y')],
+                        'Failed with axis={}, fmt={}'.format('Y', fmt))
+
+    #--- End: def
 #--- End: class
 
 if __name__ == "__main__":
